==> foundation-2.6.1.tgz: package/SocialMyspace/SocialMyspace.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialMyspace = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.841 51.036c7.792 0 14.111-6.294 14.111-14.061 0-7.765-6.319-14.061-14.111-14.061-7.798 0-14.118 6.297-14.118 14.061-.001 7.767 6.32 14.061 14.118 14.061z"
  }), /*#__PURE__*/React.createElement("ellipse", {
    cx: 47.046,
    cy: 40.984,
    rx: 12.703,
    ry: 12.656
  }), /*#__PURE__*/React.createElement("path", {
    d: "M18.214 55.984c6.313 0 11.433-5.096 11.433-11.386 0-6.292-5.12-11.39-11.433-11.39-6.315 0-11.433 5.098-11.433 11.39 0 6.291 5.117 11.386 11.433 11.386zm0 2.601c-7.25 0-12.565 6.363-12.565 12.936v4.425c0 .626.512 1.14 1.142 1.14h22.843c.632 0 1.144-.514 1.144-1.14v-4.425c0-6.573-5.315-12.936-12.564-12.936zm28.832-2.059c-8.055 0-13.962 7.071-13.962 14.376v4.917c0 .695.569 1.267 1.269 1.267h25.382a1.27 1.27 0 001.271-1.267v-4.917c.001-7.304-5.905-14.376-13.96-14.376zm31.793-2.283c-8.95 0-15.512 7.856-15.512 15.974v5.462c0 .773.632 1.407 1.41 1.407h28.2c.782 0 1.414-.635 1.414-1.407v-5.462c0-8.117-6.562-15.974-15.512-15.974z"
  }));
});
SocialMyspace.displayName = 'SocialMyspace';
export const SocialMyspaceDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialMyspace/SocialMyspace.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialMyspace = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.841 51.036c7.792 0 14.111-6.294 14.111-14.061 0-7.765-6.319-14.061-14.111-14.061-7.798 0-14.118 6.297-14.118 14.061-.001 7.767 6.32 14.061 14.118 14.061z"
  }), /*#__PURE__*/React.createElement("ellipse", {
    cx: 47.046,
    cy: 40.984,
    rx: 12.703,
    ry: 12.656
  }), /*#__PURE__*/React.createElement("path", {
    d: "M18.214 55.984c6.313 0 11.433-5.096 11.433-11.386 0-6.292-5.12-11.39-11.433-11.39-6.315 0-11.433 5.098-11.433 11.39 0 6.291 5.117 11.386 11.433 11.386zm0 2.601c-7.25 0-12.565 6.363-12.565 12.936v4.425c0 .626.512 1.14 1.142 1.14h22.843c.632 0 1.144-.514 1.144-1.14v-4.425c0-6.573-5.315-12.936-12.564-12.936zm28.832-2.059c-8.055 0-13.962 7.071-13.962 14.376v4.917c0 .695.569 1.267 1.269 1.267h25.382a1.27 1.27 0 001.271-1.267v-4.917c.001-7.304-5.905-14.376-13.96-14.376zm31.793-2.283c-8.95 0-15.512 7.856-15.512 15.974v5.462c0 .773.632 1.407 1.41 1.407h28.2c.782 0 1.414-.635 1.414-1.407v-5.462c0-8.117-6.562-15.974-15.512-15.974z"
  }));
});
SocialMyspace.displayName = 'SocialMyspace';
export var SocialMyspaceDimensions = {
  height: 100,
  width: 100
};
